# Copyright 1999-2007 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/sys-kernel/gentoo-sources/gentoo-sources-2.6.19-r3.ebuild,v 1.1 2007/01/05 14:29:09 dsd Exp $

ETYPE="sources"
K_WANT_GENPATCHES="base extras"
K_GENPATCHES_VER="5"
inherit kernel-2
detect_version
detect_arch

PATCH_COMMON=${FILESDIR}/common
PATCH_OZBRAND=${FILESDIR}/oz
PATCH_COLLIE=${FILESDIR}/collie
PATCH_TOSA=${FILESDIR}/tosa
PATCH_CONFIG=${FILESDIR}/config

KEYWORDS="~alpha ~amd64 ~ppc ~ppc64 ~sparc x86 ~arm"
HOMEPAGE="http://dev.gentoo.org/~dsd/genpatches"

DESCRIPTION="Full sources including the Gentoo patchset for the ${KV_MAJOR}.${KV_MINOR} kernel tree"
SRC_URI="${KERNEL_URI} ${GENPATCHES_URI} ${ARCH_URI}"
IUSE="${IUSE} collie poodle tosa ozbranding borzoi spitz akita c7x0 pc build eabi"
DEPEND="!build? ( sys-boot/mkimage-u-boot )"

src_compile() {
	if ( use akita ) || ( use borzoi) || ( use spitz ); then
		export MKIMAGE_PARAM="-A arm -O linux -T kernel -C none -a 0xa0008000 -e 0xa0008000"
	else
		export MKIMAGE_PARAM="-A arm -O linux -T kernel -C none -a 0xa0008000 -e 0xa0008000" #replace later
	fi

	if use pc; then
		echo "${CHOST}" | grep "x86_64" && export ARCH="x86_64" || export ARCH="i386"
	else
		export ARCH="arm"
		if use eabi; then
			export CORSS_COMPILE="armv5te-softfloat-linux-gnueabi-"
		else
			export CROSS_COMPILE="armv5te-softfloat-linux-gnu-"
		fi
	fi

	#Patching sources. First of all - general.
	if !(use pc); then
		epatch ${PATCH_COMMON}/asoc-v0.12.4.patch
		epatch ${PATCH_COMMON}/pxafb_fix_params-r1.patch
		epatch ${PATCH_COMMON}/pxa_irda_susres_fix-r0.patch
		epatch ${PATCH_COMMON}/hx2750_base-r27.patch
		epatch ${PATCH_COMMON}/hx2750_bl-r7.patch
		epatch ${PATCH_COMMON}/hx2750_pcmcia-r2.patch
		epatch ${PATCH_COMMON}/pxa_keys-r5.patch
		epatch ${PATCH_COMMON}/tsc2101-r14.patch
		epatch ${PATCH_COMMON}/hx2750_test1-r4.patch
		epatch ${PATCH_COMMON}/pxa_timerfix-r0.patch
		epatch ${PATCH_COMMON}/input_power-r6.patch
		epatch ${PATCH_COMMON}/pxa25x_cpufreq-r1.patch
		epatch ${PATCH_COMMON}/sharpsl_pm_fixes1-r0.patch
		epatch ${PATCH_COMMON}/pm_changes-r1.patch
		epatch ${PATCH_COMMON}/usb_add_epalloc-r3.patch
		epatch ${PATCH_COMMON}/usb_pxa27x_udc-r2.patch
		epatch ${PATCH_COMMON}/kexec-arm-r3.patch
		epatch ${PATCH_COMMON}/locomo_kbd_tweak-r1.patch
		epatch ${PATCH_COMMON}/poodle_pm-r3.patch
		epatch ${PATCH_COMMON}/pxa27x_overlay-r4.patch
		epatch ${PATCH_COMMON}/w100_extaccel-r0.patch
		epatch ${PATCH_COMMON}/xscale_cache_workaround-r1.patch
		epatch ${PATCH_COMMON}/serial-add-support-for-non-standard-xtals-to-16c950-driver.patch
		epatch ${PATCH_COMMON}/pxa-linking-bug.patch
		epatch ${PATCH_COMMON}/mmcsd_large_cards-r0.patch
		epatch ${PATCH_COMMON}/mmcsd_no_scr_check-r0.patch
		epatch ${PATCH_COMMON}/integrator_rgb-r1.patch
		epatch ${PATCH_COMMON}/pxa_cf_initorder_hack-r1.patch
		epatch ${PATCH_COMMON}/pxa-serial-hack.patch
		epatch ${PATCH_COMMON}/connectplus-remove-ide-HACK.patch
		epatch ${PATCH_COMMON}/squashfs3.1-2.6.19.patch
	fi
	
	if use ozbranding; then
		einfo "Building with OZ branding..."
		epatch ${PATCH_OZBRAND}/add-oz-release-string.patch
	#		epatch ${PATCH_OZBRAND}/logo_oh-r0.patch.bz2
	#		epatch ${PATCH_OZBRAND}/logo_oz-r2.patch.bz2
	fi
	
	#now - model specifing patches - configs, etc.
	if use spitz; then
		einfo "Generating for spitz (SL-C3000)"
		epatch ${PATCH_CONFIG}/spitz.patch
	fi
	
	if use c7x0; then
		einfo "Generate for c7x0 (SL-C700/SL-C750/SL-C760/SL-C860/SL-7500"
		epatch ${PATCH_CONFIG}/c7x0.patch
	fi
	
	if use borzoi; then
		einfo "Building for borzoi/terrier (SL-C3100/C3200)"
		epatch ${PATCH_CONFIG}/borzoi.patch
	fi
	
	if use akita; then
		einfo "Building for akita (SL-C1000)"
		epatch ${PATCH_CONFIG}/akita.patch
	fi
	
	if ( use collie ) || ( use poodle ); then
		epatch ${PATCH_COLLIE}/collie/mtd-sharp-flash-hack-r0.patch
		epatch ${PATCH_COLLIE}/collie/collie-r0.patch
		epatch ${PATCH_COLLIE}/collie/locomolcd-backlight-r0.patch
		epatch ${PATCH_COLLIE}/collie/ucb1x00-touch-audio-r0.patch
		epatch ${PATCH_COLLIE}/collie-mcp-r1.patch
		epatch ${PATCH_COLLIE}/collie/sa1100-udc-r0.patch
		if use collie; then
			einfo "Building for collie (SL-5000/5500)"
			epatch ${PATCH_CONFIG}/collie.patch
		else
			einfo "Building for poodle (SL-5600)"
			epatch ${PATCH_CONFIG}/poodle.patch
		fi
	fi
	
	if use tosa; then
		einfo "Building for tosa (SL-6000)"
		epatch ${PATCH_TOSA}/usb-ohci-hooks-r1.patch
		epatch ${PATCH_TOSA}/tmio-core-r4.patch
		epatch ${PATCH_TOSA}/tmio-tc6393-r8.patch
		epatch ${PATCH_TOSA}/tmio-nand-r7.patch
		epatch ${PATCH_TOSA}/tmio-ohci-r6.patch
		epatch ${PATCH_TOSA}/tmio-fb-r6.patch
		epatch ${PATCH_TOSA}/tosa-keyboard-r18.patch
		epatch ${PATCH_TOSA}/tosa-pxaac97-r6.patch
		epatch ${PATCH_TOSA}/tosa-tmio-r6.patch
		epatch ${PATCH_TOSA}/tosa-power-r17.patch
		epatch ${PATCH_TOSA}/tosa-tmio-lcd-r10.patch
		epatch ${PATCH_TOSA}/tosa-bluetooth-r8.patch
		epatch ${PATCH_TOSA}/wm97xx-lg7-r0.patch
		epatch ${PATCH_TOSA}/wm9712-suspend-cold-res-r2.patch
		epatch ${PATCH_TOSA}/sharpsl-pm-postresume-r1.patch
		epatch ${PATCH_TOSA}/wm97xx-dig-restore-r0.patch
		epatch ${PATCH_TOSA}/wm97xx-miscdevs-resume-r0.patch
		epatch ${PATCH_TOSA}/wm9712-reset-loop-r2.patch
		epatch ${PATCH_TOSA}/tosa-lcdnoise-r1.patch
		epatch ${PATCH_TOSA}/wm97xx-lcdnoise-r0.patch
		epatch ${PATCH_CONFIG}/tosa.patch
	fi

	if use build; then
		einfo "Please answer some questions..."
		einfo "Note: Recommended CMD LINE is console=ttyS0,115200n8 console=tty1 noinitrd root=/dev/mmcblk0p1 rootfstype=ext3 rw fbcon=rotate:1 rootdelay=5"
		make zImage modules #modules_install #bugbug - don't uncomment this!
		if !(use pc); then
			/usr/local/arm/mkimage ${MKIMAGE_PARAM} -n "Linux 2.6" -d arch/arm/boot/zImage kernel.img
		fi
	fi	
}

pkg_postinst() {
	kernel-2_pkg_postinst
	einfo "For more info on this patchset, and how to report problems, see:"
	einfo "${HOMEPAGE}"
	einfo "Kernel sources is installed into /usr/local/arm/src/"
}
